"""
Custom Textual widgets for KITECH Repository Manager TUI.

These widgets provide specific functionality for file management and repository browsing.
"""

__all__ = [
    "LocalPanel",
    "RemotePanel",
    "ProgressPanel",
]

# Widgets will be imported as they are implemented
# from kitech_repository.tui.widgets.local_panel import LocalPanel
# from kitech_repository.tui.widgets.remote_panel import RemotePanel
# from kitech_repository.tui.widgets.progress_panel import ProgressPanel
